@@ -352,6 +352,18 @@
         <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Name cannot be empty</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Name is unchanged</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Failed to update name</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -528,6 +540,46 @@
         <source>Move to the top of the queue</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Your browser does not support this feature</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Connection status: Firewalled</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Connection status: Connected</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Alternative speed limits: Off</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Download speed icon</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Connection status</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Alternative speed limits: On</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Upload speed icon</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Connection status: Disconnected</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>OptionsDialog</name>
@@ -1061,10 +1113,6 @@
         <source>Info: The password is saved unencrypted</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>Strict super seeding:</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>μTP-TCP mixed mode algorithm:</source>
         <translation type="unfinished" />
@@ -1105,10 +1153,6 @@
         <source>When ratio reaches</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>sec</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>When seeding time reaches</source>
         <translation type="unfinished" />
@@ -1225,10 +1269,6 @@
         <source>Fixed slots</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>Resolve peer countries (GeoIP):</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>Advanced</source>
         <translation type="unfinished" />
@@ -1282,7 +1322,31 @@
         <translation type="unfinished" />
     </message>
     <message>
-        <source>Listen on IPv6 address (requires restart):</source>
+        <source>Resolve peer countries:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>ban for:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stop tracker timeout:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Ban client after consecutive failures:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Enable cookie Secure flag (requires HTTPS)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>UPnP lease duration [0: Permanent lease]:</source>
         <translation type="unfinished" />
     </message>
 </context>
@@ -1344,10 +1408,6 @@
         <comment>i.e. files that are being downloaded right now</comment>
         <translation>Skrár</translation>
     </message>
-    <message>
-        <source>Country</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>Ban peer permanently</source>
         <translation type="unfinished" />
@@ -1364,6 +1424,10 @@
         <source>Add a new peer...</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Country/Region</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>PropListDelegate</name>
@@ -1565,6 +1629,10 @@
         <source>Filter files...</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Rename...</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>ScanFoldersModel</name>
@@ -1741,6 +1809,30 @@
         <source>Errored (%1)</source>
         <translation>Villur (%1)</translation>
     </message>
+    <message>
+        <source>Stalled Uploading (%1)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled Downloading (%1)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled Downloading (0)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled (0)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled Uploading (0)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled (%1)</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>TorrentContentModel</name>
@@ -2605,6 +2697,14 @@
         <source>Version</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Yes</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>No</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>PeersAdditionDialog</name>
@@ -2725,10 +2825,6 @@
         <source>About qBittorrent</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>Libraries</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>License</source>
         <translation type="unfinished" />
@@ -2749,6 +2845,14 @@
         <source>Author</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Software Used</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>OptionDialog</name>
@@ -2756,6 +2860,14 @@
         <source>All addresses</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>All IPv6 addresses</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>All IPv4 addresses</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>SearchJobWidget</name>
@@ -2784,4 +2896,15 @@
         <translation type="unfinished" />
     </message>
 </context>
+<context>
+    <name>TorrentContentTreeView</name>
+    <message>
+        <source>Renaming</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>New name:</source>
+        <translation type="unfinished" />
+    </message>
+</context>
 </TS>
\ No newline at end of file
