@@ -528,6 +528,38 @@
         <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Connection status: Firewalled</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Connection status: Connected</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Alternative speed limits: Off</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Download speed icon</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Connection status</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Alternative speed limits: On</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Upload speed icon</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Connection status: Disconnected</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>OptionsDialog</name>
@@ -1061,10 +1093,6 @@
         <source>Info: The password is saved unencrypted</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>Strict super seeding:</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>μTP-TCP mixed mode algorithm:</source>
         <translation type="unfinished" />
@@ -1105,10 +1133,6 @@
         <source>When ratio reaches</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>sec</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>When seeding time reaches</source>
         <translation type="unfinished" />
@@ -1225,10 +1249,6 @@
         <source>Fixed slots</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>Resolve peer countries (GeoIP):</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>Advanced</source>
         <translation type="unfinished" />
@@ -1282,7 +1302,31 @@
         <translation type="unfinished" />
     </message>
     <message>
-        <source>Listen on IPv6 address (requires restart):</source>
+        <source>Resolve peer countries:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>ban for:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stop tracker timeout:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Ban client after consecutive failures:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Enable cookie Secure flag (requires HTTPS)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>UPnP lease duration [0: Permanent lease]:</source>
         <translation type="unfinished" />
     </message>
 </context>
@@ -1344,10 +1388,6 @@
         <comment>i.e. files that are being downloaded right now</comment>
         <translation>Fișiere</translation>
     </message>
-    <message>
-        <source>Country</source>
-        <translation>Țară</translation>
-    </message>
     <message>
         <source>Ban peer permanently</source>
         <translation type="unfinished" />
@@ -1364,6 +1404,10 @@
         <source>Add a new peer...</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Country/Region</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>PropListDelegate</name>
@@ -1745,6 +1789,30 @@
         <source>Errored (%1)</source>
         <translation>Cu erori (%1)</translation>
     </message>
+    <message>
+        <source>Stalled Uploading (%1)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled Downloading (%1)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled Downloading (0)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled (0)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled Uploading (0)</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Stalled (%1)</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>TorrentContentModel</name>
@@ -2709,10 +2777,6 @@
         <source>About qBittorrent</source>
         <translation type="unfinished" />
     </message>
-    <message>
-        <source>Libraries</source>
-        <translation type="unfinished" />
-    </message>
     <message>
         <source>License</source>
         <translation type="unfinished" />
@@ -2733,6 +2797,14 @@
         <source>Author</source>
         <translation type="unfinished" />
     </message>
+    <message>
+        <source>Software Used</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>OptionDialog</name>
