@@ -274,7 +274,7 @@
     </message>
     <message>
         <source>Download Torrents from their URLs or Magnet links</source>
-        <translation>Torrent'leri URL'lerinden ya da Magnet bağlantılarından indir</translation>
+        <translation>Torrent'leri URL'lerinden ya da Magnet bağlantılarından indirin</translation>
     </message>
     <message>
         <source>Upload local torrent</source>
@@ -348,6 +348,18 @@
         <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
         <translation>JavaScript Gerekli! Web Arayüzünün düzgün çalışması için JavaScript'i etkinleştirmek zorundasınız</translation>
     </message>
+    <message>
+        <source>Name cannot be empty</source>
+        <translation>Ad boş olamaz</translation>
+    </message>
+    <message>
+        <source>Name is unchanged</source>
+        <translation>Ad değişmedi</translation>
+    </message>
+    <message>
+        <source>Failed to update name</source>
+        <translation>Adı güncelleme başarısız</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -508,6 +520,46 @@
         <source>Move to the top of the queue</source>
         <translation>Kuyruğun en üstüne taşı</translation>
     </message>
+    <message>
+        <source>Your browser does not support this feature</source>
+        <translation>Tarayıcınız bu özelliği desteklemiyor</translation>
+    </message>
+    <message>
+        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
+        <translation>Bu özelliği kullanmak için Web Arayüzü'ne HTTPS üzerinden erişilmesi gerekir</translation>
+    </message>
+    <message>
+        <source>Connection status: Firewalled</source>
+        <translation>Bağlantı durumu: Güvenlik Duvarlı</translation>
+    </message>
+    <message>
+        <source>Connection status: Connected</source>
+        <translation>Bağlantı durumu: Bağlandı</translation>
+    </message>
+    <message>
+        <source>Alternative speed limits: Off</source>
+        <translation>Alternatif hız sınırları: Kapalı</translation>
+    </message>
+    <message>
+        <source>Download speed icon</source>
+        <translation>İndirme hızı simgesi</translation>
+    </message>
+    <message>
+        <source>Connection status</source>
+        <translation>Bağlantı durumu</translation>
+    </message>
+    <message>
+        <source>Alternative speed limits: On</source>
+        <translation>Alternatif hız sınırları: Açık</translation>
+    </message>
+    <message>
+        <source>Upload speed icon</source>
+        <translation>Gönderme hızı simgesi</translation>
+    </message>
+    <message>
+        <source>Connection status: Disconnected</source>
+        <translation>Bağlantı durumu: Bağlantı Kesildi</translation>
+    </message>
 </context>
 <context>
     <name>OptionsDialog</name>
@@ -927,7 +979,7 @@
     </message>
     <message>
         <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
-        <translation>Siteler Arası İstek Sahteciliği (CSRF) korumasını etkinleştir</translation>
+        <translation>Siteler Arası İstek Sahtekarlığı (CSRF) korumasını etkinleştir</translation>
     </message>
     <message>
         <source>Delete .torrent files afterwards</source>
@@ -975,7 +1027,7 @@
     </message>
     <message>
         <source>Relocate affected torrents</source>
-        <translation>Etkilenmiş torrent'lerin yerini değiştir</translation>
+        <translation>Etkilenen torrent'lerin yerini değiştir</translation>
     </message>
     <message>
         <source>Apply rate limit to peers on LAN</source>
@@ -1015,11 +1067,11 @@
     </message>
     <message>
         <source>Switch affected torrents to Manual Mode</source>
-        <translation>Etkilenmiş torrent'leri Elle Kipine değiştir</translation>
+        <translation>Etkilenen torrent'leri Elle Kipine değiştir</translation>
     </message>
     <message>
         <source>Files location:</source>
-        <translation>Dosyalar konumu:</translation>
+        <translation>Dosyaların konumu:</translation>
     </message>
     <message>
         <source>Manual</source>
@@ -1043,7 +1095,7 @@
     </message>
     <message>
         <source>Strict super seeding:</source>
-        <translation>Değişmez süper gönderim:</translation>
+        <translation type="vanished">Değişmez süper gönderim:</translation>
     </message>
     <message>
         <source>μTP-TCP mixed mode algorithm:</source>
@@ -1085,10 +1137,6 @@
         <source>When ratio reaches</source>
         <translation>Oran şu değere ulaştığında</translation>
     </message>
-    <message>
-        <source>sec</source>
-        <translation>san</translation>
-    </message>
     <message>
         <source>When seeding time reaches</source>
         <translation>Gönderim şu süreye ulaştığında</translation>
@@ -1147,7 +1195,7 @@
     </message>
     <message>
         <source>Outgoing ports (Min) [0: Disabled]:</source>
-        <translation>Giden b.noktaları (En az) [0: Etkisizleştirildi]:</translation>
+        <translation>Giden bağlantı noktaları (En az) [0: Etkisizleştirildi]</translation>
     </message>
     <message>
         <source>IP Address to report to trackers (requires restart):</source>
@@ -1179,7 +1227,7 @@
     </message>
     <message>
         <source>Outgoing ports (Max) [0: Disabled]:</source>
-        <translation>Giden b.noktaları (En fazla) [0: Etkisizleştirildi]:</translation>
+        <translation>Giden bağlantı noktaları (En fazla) [0: Etkisizleştirildi]</translation>
     </message>
     <message>
         <source>Asynchronous I/O threads:</source>
@@ -1205,10 +1253,6 @@
         <source>Fixed slots</source>
         <translation>Sabit yuvalar</translation>
     </message>
-    <message>
-        <source>Resolve peer countries (GeoIP):</source>
-        <translation>Kişi ülkelerini çöz (GeoIP):</translation>
-    </message>
     <message>
         <source>Advanced</source>
         <translation>Gelişmiş</translation>
@@ -1262,8 +1306,32 @@
         <translation>Oturum zaman aşımı:</translation>
     </message>
     <message>
-        <source>Listen on IPv6 address (requires restart):</source>
-        <translation>IPv6 adresinde dinle (yeniden başlatma gerektirir):</translation>
+        <source>Resolve peer countries:</source>
+        <translation>Kişi ülkelerini çöz:</translation>
+    </message>
+    <message>
+        <source>ban for:</source>
+        <translation>yasaklama süresi:</translation>
+    </message>
+    <message>
+        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
+        <translation>Parça kapsam benzeşimi kullan (libtorrent &gt;= 1.2.2 gerektirir):</translation>
+    </message>
+    <message>
+        <source>Stop tracker timeout:</source>
+        <translation>İzleyiciyi durdurma zaman aşımı:</translation>
+    </message>
+    <message>
+        <source>Ban client after consecutive failures:</source>
+        <translation>Art arda şu kadar hatadan sonra istemciyi yasakla:</translation>
+    </message>
+    <message>
+        <source>Enable cookie Secure flag (requires HTTPS)</source>
+        <translation>Tanımlama bilgisi Güvenli işaretini etkinleştir (HTTPS gerektirir)</translation>
+    </message>
+    <message>
+        <source>UPnP lease duration [0: Permanent lease]:</source>
+        <translation>UPnP kiralama süresi [0: Kalıcı kiralama]:</translation>
     </message>
 </context>
 <context>
@@ -1324,10 +1392,6 @@
         <comment>i.e. files that are being downloaded right now</comment>
         <translation>Dosyalar</translation>
     </message>
-    <message>
-        <source>Country</source>
-        <translation>Ülke</translation>
-    </message>
     <message>
         <source>Ban peer permanently</source>
         <translation>Kişiyi kalıcı olarak yasakla</translation>
@@ -1344,6 +1408,10 @@
         <source>Add a new peer...</source>
         <translation>Yeni bir kişi ekle...</translation>
     </message>
+    <message>
+        <source>Country/Region</source>
+        <translation>Ülke/Bölge</translation>
+    </message>
 </context>
 <context>
     <name>PropListDelegate</name>
@@ -1545,6 +1613,10 @@
         <source>Filter files...</source>
         <translation>Dosyaları süzün...</translation>
     </message>
+    <message>
+        <source>Rename...</source>
+        <translation>Yeniden adlandır...</translation>
+    </message>
 </context>
 <context>
     <name>ScanFoldersModel</name>
@@ -1667,7 +1739,7 @@
     </message>
     <message>
         <source>Resumed (0)</source>
-        <translation>Devam edildi (0)</translation>
+        <translation>Devam Edildi (0)</translation>
     </message>
     <message>
         <source>Paused (0)</source>
@@ -1679,11 +1751,11 @@
     </message>
     <message>
         <source>Inactive (0)</source>
-        <translation>Etkin değil (0)</translation>
+        <translation>Etkin Değil (0)</translation>
     </message>
     <message>
         <source>Errored (0)</source>
-        <translation>Hata oldu (0)</translation>
+        <translation>Hata Oldu (0)</translation>
     </message>
     <message>
         <source>All (%1)</source>
@@ -1707,7 +1779,7 @@
     </message>
     <message>
         <source>Resumed (%1)</source>
-        <translation>Devam edildi (%1)</translation>
+        <translation>Devam Edildi (%1)</translation>
     </message>
     <message>
         <source>Active (%1)</source>
@@ -1715,11 +1787,35 @@
     </message>
     <message>
         <source>Inactive (%1)</source>
-        <translation>Etkin değil (%1)</translation>
+        <translation>Etkin Değil (%1)</translation>
     </message>
     <message>
         <source>Errored (%1)</source>
-        <translation>Hata oldu (%1)</translation>
+        <translation>Hata Oldu (%1)</translation>
+    </message>
+    <message>
+        <source>Stalled Uploading (%1)</source>
+        <translation>Durdurulan Gönderme (%1)</translation>
+    </message>
+    <message>
+        <source>Stalled Downloading (%1)</source>
+        <translation>Durdurulan İndirme (%1)</translation>
+    </message>
+    <message>
+        <source>Stalled Downloading (0)</source>
+        <translation>Durdurulan İndirme (0)</translation>
+    </message>
+    <message>
+        <source>Stalled (0)</source>
+        <translation>Durduruldu (0)</translation>
+    </message>
+    <message>
+        <source>Stalled Uploading (0)</source>
+        <translation>Durdurulan Gönderme (0)</translation>
+    </message>
+    <message>
+        <source>Stalled (%1)</source>
+        <translation>Durduruldu (%1)</translation>
     </message>
 </context>
 <context>
@@ -2029,7 +2125,7 @@
     </message>
     <message>
         <source>Errored</source>
-        <translation>Hata oldu</translation>
+        <translation>Hata Oldu</translation>
     </message>
     <message>
         <source>[F] Downloading</source>
@@ -2061,7 +2157,7 @@
     </message>
     <message>
         <source>Stalled</source>
-        <translation>Askıda</translation>
+        <translation>Durduruldu</translation>
     </message>
 </context>
 <context>
@@ -2298,7 +2394,7 @@
     </message>
     <message>
         <source>Also delete the files on the hard disk</source>
-        <translation>Aynı zamanda sabit diskteki dosyaları sil</translation>
+        <translation>Aynı zamanda sabit diskteki dosyaları da sil</translation>
     </message>
     <message>
         <source>Deletion confirmation - qBittorrent</source>
@@ -2466,7 +2562,7 @@
     </message>
     <message>
         <source>Only enabled</source>
-        <translation>Sadece etkinleştirilmişler</translation>
+        <translation>Sadece etkinleştirilenler</translation>
     </message>
     <message>
         <source>out of</source>
@@ -2557,6 +2653,14 @@
         <source>Version</source>
         <translation>Sürüm</translation>
     </message>
+    <message>
+        <source>Yes</source>
+        <translation>Evet</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>Hayır</translation>
+    </message>
 </context>
 <context>
     <name>PeersAdditionDialog</name>
@@ -2677,10 +2781,6 @@
         <source>About qBittorrent</source>
         <translation>qBittorrent Hakkında</translation>
     </message>
-    <message>
-        <source>Libraries</source>
-        <translation>Kütüphaneler</translation>
-    </message>
     <message>
         <source>License</source>
         <translation>Lisans</translation>
@@ -2701,6 +2801,14 @@
         <source>Author</source>
         <translation>Hazırlayan</translation>
     </message>
+    <message>
+        <source>Software Used</source>
+        <translation>Kullanılan Yazılımlar</translation>
+    </message>
+    <message>
+        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
+        <translation>DB-IP tarafından sunulan ücretsiz IP to Country Lite veritabanı kişilerin ülkelerinin çözülmesi için kullanılır. Veritabanı Creative Commons Attribution 4.0 Uluslararası Lisansı altında lisanslanmıştır</translation>
+    </message>
 </context>
 <context>
     <name>OptionDialog</name>
@@ -2708,6 +2816,14 @@
         <source>All addresses</source>
         <translation>Tüm adresler</translation>
     </message>
+    <message>
+        <source>All IPv6 addresses</source>
+        <translation>Tüm IPv6 adresleri</translation>
+    </message>
+    <message>
+        <source>All IPv4 addresses</source>
+        <translation>Tüm IPv4 adresleri</translation>
+    </message>
 </context>
 <context>
     <name>SearchJobWidget</name>
@@ -2736,4 +2852,15 @@
         <translation>İndirme bağlantısı</translation>
     </message>
 </context>
+<context>
+    <name>TorrentContentTreeView</name>
+    <message>
+        <source>Renaming</source>
+        <translation>Yeniden adlandır</translation>
+    </message>
+    <message>
+        <source>New name:</source>
+        <translation>Yeni adı:</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
